##  Subtype of the Data Object
The integration will try to match the data object fact sheet’s subtype with the asset type used in Collibra. If a match is found, the Subtype field is populated accordingly. Otherwise, it will remain empty.
